# NRP_NICU Example Dataset

A dataset on treatment and outcomes of non-vigorous infants admitted to the Neonatal Intensive Care Unit (NICU), 
before and after a change to treatment guidelines was implemented.

### Source
Dataset and research goal are based on:

**Saint-Fleur AL, Alcalá HE, Sridhar S (2023)** <br>
"Outcomes of neonates born through meconium-stained amniotic fluid pre and post 2015 NRP guideline implementation.",
*PLoS ONE* 18(8): [e0289945](https://doi.org/10.1371/journal.pone.0289945)

### Example data-to-paper manuscript
Here is an [example Paper](https://github.com/rkishony/data-to-paper-supplementary/blob/main/Supplementary%20Data-chained%20Manuscripts/Supplementary%20Data-chained%20Manuscript%20C.pdf) created by data-to paper.

### How to run
`python run.py npr_nicu`
